

#from vc_hid import vc_hid as hid
import vc_hid  

pid="89a"
pid1="867"
setID="28"
readID="29"
controlID=1
readnumber=20


if(__name__)=="__main__":
    anotherCMD=[0,0,0,0]
    test = vc_hid.HID_class()

    passflag,data=test.hidset(pid,setID,controlID,readnumber,anotherCMD)
    print(passflag,data)

    
    passflag,data=test.readhid(pid,readID,controlID,readnumber)  
    print(passflag,data)
   











import setuptools

with open("README.txt", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="vc_hid", # Replace with your own username
    version="2021.3.11",
    author="lorry_rui",
    author_email="lrui@logitech.com",
    description="logitech HID command package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Lorrytoolcenter/VC-HID.git",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
)
